#!/bin/bash

if [ "$BASH_VERSION" = "" ] ; then
	echo "This is a Bash script. Please either start it normally (e.g.: \"./script.sh\"), or with Bash directly (e.g.: \"bash script.sh\")"
	exit
fi

cd "$(dirname "$0")"
export LOCALDIR=$(pwd)
source "$LOCALDIR/support/winewrap.shlib"

NAME="Pro Motion NG"
SFNAME_DEF="cosmigo-pro-motion-ng.desktop"
if [ ! -v WINEWRAP_UDATA_ROOT ] ; then
	WINEWRAP_UDATA_ROOT="$HOME/.local/share"
fi
UDATAPATH="$WINEWRAP_UDATA_ROOT/pro_motion_ng"
ICON_DEFAULT="pro-motion-icon-128.png"
ICON="$LOCALDIR/support/$ICON_DEFAULT"
SCRIPTNAME=$(basename "$0")
STARTOPT=""
DTNAME="Pro-Motion-NG"
DEFWD="$LOCALDIR/app"
USEWD=""
STARTCMD="pmotion.exe"
SCCATS_DEF="Graphics;2DGraphics;"
SCARGS_DEF=": %f"
SCNAME=""
SCPATH=""
SFNAME=""
SCARGS=""
SCCATS=""
WRAP_CHECK_RES=0
WRAP_RESET_GAMMA=0
WAIT_FOR_WINESERVER=1

export PATH="$LOCALDIR/wine/bin:$PATH"
export WINE="$LOCALDIR/wine/bin/wine"
export WINELOADER="$LOCALDIR/wine/bin/wine"
export WINEVERPATH="$LOCALDIR/wine"
export WINESERVER="$LOCALDIR/wine/bin/wineserver"
export WINEDLLPATH="$LOCALDIR/wine/lib/wine/fakedlls"
if [ -d "$LOCALDIR/prefix" ] ; then
	export WINEPREFIX="$LOCALDIR/prefix"
else
	export WINEPREFIX="$UDATAPATH/prefix"
fi
export WINETRICKS="$LOCALDIR/support/winetricks"
if [ ! -v WINEDEBUG ] ; then
	export WINEDEBUG=-all
fi

if [ "$1" == "kill" ] ; then
	"$WINESERVER" -k
	exit
fi

get_desktop_res
if [ "$?" != 0 ] ; then
	exit
fi
get_display_gamma

while [ "$1" != "" ] ; do
	if [ "$1" == ":" ] ; then
		shift
		break
	fi
	ARGSTR=$(echo $1 | awk -F'=' '{print $1}')
	if [ "$ARGSTR" == "menu" ] || [ "$ARGSTR" == "start" ] || [ "$ARGSTR" == "run" ] || [ "$ARGSTR" == "runwine" ] || [ "$ARGSTR" == "shortcut" ] || [ "$ARGSTR" == "-s" ] ; then
		if [ "$STARTOPT" != "" ] ; then
			echo "ERROR: Multiple start options specified"
			exit
		fi
		STARTOPT="$ARGSTR"
		if [ "$ARGSTR" == "runwine" ] ; then
			STARTCMD="${1:8}"
		elif [ "$ARGSTR" == "run" ] ; then
			STARTCMD="${1:4}"
		fi
	elif [ "$ARGSTR" == "cd" ] ; then
		USEWD="${1:3}"
		winpath_to_prefix USEWD
	elif [ "$ARGSTR" == "desktop" ] ; then
		WRAP_DT_RES="${1:8}"
	elif [ "$ARGSTR" == "icon" ] ; then
		ICON="$(echo ${1:5} | awk '{$1=$1};1')"
		if [ "${ICON:0:1}" != "/" ] ; then
			ICON="$LOCALDIR/support/$ICON"
		fi
		if [ ! -f "$ICON" ] ; then
			echo "Icon missing or not specified."
			ICON="$LOCALDIR/support/$ICON_DEFAULT"
		fi
	elif [ "$ARGSTR" == "scl" ] ; then
		SCPATH="${1:4}"
	elif [ "$ARGSTR" == "scn" ] ; then
		SCNAME="$(echo ${1:4} | awk '{$1=$1};1')"
		if [ "$SCNAME" == "" ] ; then
			echo "Shortcut name cannot be blank!"
			exit
		fi
	elif [ "$ARGSTR" == "sfn" ] ; then
		SFNAME="$(echo ${1:4} | awk '{$1=$1};1')"
		if [ "$SFNAME" == "" ] ; then
			echo "Shortcut filename cannot be blank!"
			exit
		fi
		if [ "${SFNAME: -8}" != ".desktop" ] ; then
			SFNAME="$SFNAME.desktop"
		fi
	elif [ "$ARGSTR" == "sca" ] ; then
		SCARGS="${1:4}"
	elif [ "$ARGSTR" == "scc" ] ; then
		SCCATS="${1:4}"
	elif [ "$ARGSTR" == "checkres" ] ; then
		if [ "${1:9}" == "0" ] ; then
			echo "Post-run resolution check disabled"
			WRAP_CHECK_RES=0
		else
			echo "Post-run resolution check enabled"
			WRAP_CHECK_RES=1
		fi
	elif [ "$ARGSTR" == "resetgamma" ] ; then
		if [ "${1:11}" == "0" ] ; then
			echo "Post-run gamma reset disabled"
			WRAP_RESET_GAMMA=0
		else
			echo "Post-run gamma reset enabled"
			WRAP_RESET_GAMMA=1
		fi
	else
		echo "Unrecognised argument: $1"
		exit
	fi
	shift
done

if [ -f "$LOCALDIR/support/desktop" ] && [ ! -v WRAP_DT_RES ] ; then
	WRAP_DT_RES=$(head -n1 "$LOCALDIR/support/desktop")
fi

if [ -v WRAP_DT_RES ] ; then
	if [ "$WRAP_DT_RES" == "" ] || [ "${WRAP_DT_RES:0:1}" == " " ] || [ "${WRAP_DT_RES:0:1}" == "	" ] || [ "${WRAP_DT_RES:0:1}" == "d" ] || [ "${WRAP_DT_RES:0:1}" == "D" ] ; then
		WRAP_DT_RES=$CURRENT_RES
	elif [ "${WRAP_DT_RES:0:1}" == "0" ] ; then
		WRAP_DT_RES=""
	fi
fi

# Check userdata

init_prefix

if [ "$?" == "3" ] ; then
	env WINEDLLOVERRIDES=mshtml,mscoree,winemenubuilder.exe=d "$WINE" reg add "HKCU\Software\Wine\DllOverrides" /v winemenubuilder.exe /d "" /f
fi

export PM_DOCS_PATH=$(xdg-user-dir DOCUMENTS)
if [ "$PM_DOCS_PATH" == "" ] ; then
	if [ -d "$HOME/Documents" ] ; then
		PM_DOCS_PATH="$HOME/Documents"
	else
		PM_DOCS_PATH=$HOME
	fi
fi

if (! "$WINE" reg query "HKCU\Software\Cosmigo\Pro Motion 7\license" /v key >/dev/null) ; then
	KEYFILE="$(ls "$PM_DOCS_PATH/"*.pmk -1 2>/dev/null | head -n1)"
	if [ "$KEYFILE" == "" ] ; then
		KEYFILE="$(ls "$LOCALDIR/support/"*.pmk -1 2>/dev/null | head -n1)"
	fi
	if [ "$KEYFILE" != "" ] ; then
		echo "Importing license file: $KEYFILE"
		"$WINE" reg add "HKCU\Software\Cosmigo\Pro Motion 7\license" /v key /d "$(cat "$KEYFILE")" /f
	fi
fi

PM_DOCS_PATH="Z:${PM_DOCS_PATH//\//\\}"



run_app() {
if [ "$(xdg-mime query default application/x-pro-motion-project)" != "cosmigo-pro-motion-ng.desktop" ] && [ ! -e "$WINEPREFIX/no-file-assoc-check" ] && ([ -e /usr/share/applications/cosmigo-pro-motion-ng.desktop ] || [ -e "$HOME/.local/share/applications/cosmigo-pro-motion-ng.desktop" ]) ; then
	if (zenity --question --window-icon="$ICON" --width=300 --text="It looks like Pro Motion is not currently set as the default handler for Pro Motion project files (*.pmp).\n\nWould you like to change this?") ; then
		xdg-mime default cosmigo-pro-motion-ng.desktop application/x-pro-motion-project
	fi
fi
cd "$DEFWD"
run_wine : wait=0 : "$STARTCMD" "$@"
}

show_menu() {
MENUSTR=$(zenity --list --hide-header --title="$NAME" --window-icon="$ICON" --width=300 --height=175 --text="${NAME//&/&amp;}" --column="Launch options:" \
	"Launch Pro Motion NG" \
	"Create shortcut..." \
	"Advanced options..." )
if [ "$MENUSTR" == "Launch Pro Motion NG" ] ; then
	run_app "$@"
elif [ "$MENUSTR" == "Create shortcut..." ] ; then
	create_sc_gui
elif [ "$MENUSTR" == "Advanced options..." ] ; then
	winewrap_menu
fi
}


if [ "$STARTOPT" == "menu" ] ; then
	show_menu "$@"
elif [ "$STARTOPT" == "shortcut" ] || [ "$STARTOPT" == "-s" ] ; then
	if [ "$SCPATH" == "" ] ; then
		create_sc_gui
	else
		create_shortcut "$SCNAME" "$SCPATH" "$SFNAME" "$SCARGS" "$SCCATS" "$ICON"
	fi
elif [ "$STARTOPT" == "start" ] ; then
	run_app "$@"
elif [ "$STARTOPT" == "run" ] ; then
	cd "$USEWD"
	$STARTCMD "$@"
elif [ "$STARTOPT" == "runwine" ] ; then
	cd "$DEFWD"
	cd "$USEWD"
	if [ "$STARTCMD" != "" ] ; then
		run_wine "$STARTCMD" "$@"
	elif [ "$1" != "" ] ; then
		run_wine "$@"
	else
		run_wine_gui
	fi
elif [ "$STARTOPT" == "" ] ; then
	run_app "$@"
else
	echo "Unrecognised start option: $STARTOPT"
fi
