#!/bin/bash
# This script should create/recreate the menu shortcut and set/reset the Pro Motion Project MIME type & association.
# Run as root to apply it system-wide (if you do this make sure that Pro Motion is installed somewhere like /opt
# and that all users have read access to it)

if [ "$BASH_VERSION" = "" ] ; then
	echo "This is a Bash script. Please either start it normally (e.g.: \"./script.sh\"), or with Bash directly (e.g.: \"bash script.sh\")"
	exit
fi

cd "$(dirname "$0")"
WRAPPERDIR="$(dirname "$(pwd)")"

if [ "$(pwd)" != "$WRAPPERDIR/support" ] || [ ! -e "$WRAPPERDIR/start.sh" ] ; then
	echo "Error: this script does not appear to be in the wrapper's support directory or the wrapper's start script is missing."
	exit
fi

if [ "$(id -u)" == "0" ] ; then
	SC_DEST="/usr/share/applications"
	MIMEDB_LOC="/usr/share/mime"
else
	if [ ! -e "$HOME/.local/share/applications" ] ; then
		mkdir -p "$HOME/.local/share/applications"
	fi
	if [ ! -e "$HOME/.local/share/mime/packages" ] ; then
		mkdir -p "$HOME/.local/share/mime/packages"
	fi
	SC_DEST="$HOME/.local/share/applications"
	MIMEDB_LOC="$HOME/.local/share/mime"
fi

# Install app icon

for SIZE in 128 64 32 16 ; do
	xdg-icon-resource install --context apps --size $SIZE pro-motion-icon-$SIZE.png cosmigo-pro-motion-icon
done

# Install MIME type for Pro Motion projects

cp x-pro-motion-project.xml "$MIMEDB_LOC/packages"
update-mime-database "$MIMEDB_LOC"

# Copy default shortcut/menu entry and update to associate it with *.pmp

sed -e "/^Exec=/ c Exec=\"$WRAPPERDIR/start.sh\" : %f" cosmigo-pro-motion-ng.desktop >"$SC_DEST/cosmigo-pro-motion-ng.desktop"
update-desktop-database "$SC_DEST"
